@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2012-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -16,8 +16,8 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-#ifndef IMPORTLOGWIDGET_H
-#define IMPORTLOGWIDGET_H
+#ifndef CUSTOMLOGWIDGET_H
+#define CUSTOMLOGWIDGET_H
 
 #include "kdepim_export.h"
 #include <QStyledItemDelegate>
@@ -52,9 +52,9 @@ public:
     void addTitleLogEntry(const QString &log);
     void addEndLineLogEntry();
 
-    QString toHtml() const;
-    QString toPlainText() const;
-    bool isEmpty() const;
+    Q_REQUIRED_RESULT QString toHtml() const;
+    Q_REQUIRED_RESULT QString toPlainText() const;
+    Q_REQUIRED_RESULT bool isEmpty() const;
 
 private:
     enum ItemType {
@@ -70,4 +70,4 @@ private:
 };
 }
 
-#endif /* IMPORTLOGWIDGET_H */
+#endif /* CUSTOMLOGWIDGET_H */
